@@ -6,9 +6,9 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. 
  */
  
- "use strict";
+"use strict";
 
-var { DeferredTask } = ChromeUtils.import("resource://gre/modules/DeferredTask.jsm");
+var { DeferredTask } = ChromeUtils.importESModule("resource://gre/modules/DeferredTask.sys.mjs");
 
 var db = {
 
@@ -62,51 +62,6 @@ var db = {
         return "MZTB" + uuid;
     }
     
-    // try to migrate old accounts file from TB60
-    if (!this.files["accounts"].found) {
-      try {
-        let accounts = await IOUtils.readJSON(TbSync.io.getAbsolutePath("accounts.json"));
-        for (let d of Object.values(accounts.data)) {
-          console.log("Migrating: " + JSON.stringify(d));
-          
-          let settings = {};
-          settings.status = "disabled";
-          settings.provider = d.provider;
-          settings.https = (d.https == "1");
-          
-          switch (d.provider) {
-            case "dav":
-              settings.calDavHost = d.host ? d.host : "";
-              settings.cardDavHost = d.host2 ? d.host2 : "";
-              settings.serviceprovider = d.serviceprovider;
-              settings.user = d.user;
-              settings.syncGroups = (d.syncGroups == "1");
-              settings.useCalendarCache = (d.useCache == "1");
-            break;
-            
-            case "eas":
-              settings.useragent = d.useragent;
-              settings.devicetype = d.devicetype;
-              settings.deviceId = getNewDeviceId4Migration();
-              settings.asversionselected = d.asversionselected;
-              settings.asversion = d.asversion;
-              settings.host = d.host;
-              settings.user = d.user;
-              settings.servertype = d.servertype;
-              settings.seperator = d.seperator;
-              settings.provision = (d.provision == "1");
-              settings.displayoverride = (d.displayoverride == "1");
-              if (d.hasOwnProperty("galautocomplete")) settings.galautocomplete = (d.galautocomplete == "1");
-            break;
-          }
-          
-          this.addAccount(d.accountname, settings);
-        }
-      } catch (e) {
-        Components.utils.reportError(e);
-      }
-    }
-    
     this.loaded = true;
   },
   
