@@ -6,11 +6,11 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. 
  */
  
- "use strict";
+"use strict";
 
- var { XPCOMUtils } = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
- 
- XPCOMUtils.defineLazyModuleGetters(this, {
+var { XPCOMUtils } = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
+
+XPCOMUtils.defineLazyModuleGetters(this, {
   CalAlarm: "resource:///modules/CalAlarm.jsm",
   CalAttachment: "resource:///modules/CalAttachment.jsm",
   CalAttendee: "resource:///modules/CalAttendee.jsm",
@@ -26,7 +26,7 @@ var lightning = {
   load: async function () {
     try {
       TbSync.lightning.cal = ChromeUtils.import("resource:///modules/calendar/calUtils.jsm").cal;
-      TbSync.lightning.ICAL = ChromeUtils.import("resource:///modules/calendar/Ical.jsm").ICAL;
+      TbSync.lightning.ICAL = ChromeUtils.importESModule("resource:///modules/calendar/Ical.sys.mjs").default;
       let manager = TbSync.lightning.cal.manager;
       manager.addCalendarObserver(this.calendarObserver);
       manager.addObserver(this.calendarManagerObserver);
@@ -254,8 +254,8 @@ var lightning = {
       this._tbCalendar = TbCalendar;
       this._item = item;
       
-      this._isTodo = (item instanceof Ci.calITodo);
-      this._isEvent = (item instanceof Ci.calIEvent);
+      this._isTodo = item.isTodo ? item.isTodo() : (item instanceof Ci.calITodo);
+      this._isEvent = item.isEvent ? item.isEvent() :  (item instanceof Ci.calIEvent);
     }
     
     get tbCalendar() {
