@@ -6,8 +6,11 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. 
  */
  
- "use strict";
- 
+"use strict";
+
+var { AddonManager } = ChromeUtils.import("resource://gre/modules/AddonManager.jsm");
+var { MailServices } = ChromeUtils.import("resource:///modules/MailServices.jsm");
+
 var providers = {
 
   //list of default providers (available in add menu, even if not installed)
@@ -15,9 +18,6 @@ var providers = {
     "google" : {
       name: "Google's People API", 
       homepageUrl: "https://addons.thunderbird.net/addon/google-4-tbsync/"},
-    "dav" : {
-      name: "CalDAV & CardDAV", 
-      homepageUrl: "https://addons.thunderbird.net/addon/dav-4-tbsync/"},
     "eas" : {
       name: "Exchange ActiveSync", 
       homepageUrl: "https://addons.thunderbird.net/addon/eas-4-tbsync/"},
